@@ -23,17 +23,16 @@
 namespace brpc {
 
 EventDispatcher::EventDispatcher()
-    : _epfd(-1)
+    : _event_dispatcher_fd(-1)
     , _stop(false)
     , _tid(0)
-    , _consumer_thread_attr(BTHREAD_ATTR_NORMAL)
-{
-    _epfd = epoll_create(1024 * 1024);
-    if (_epfd < 0) {
+    , _thread_attr(BTHREAD_ATTR_NORMAL) {
+    _event_dispatcher_fd = epoll_create(1024 * 1024);
+    if (_event_dispatcher_fd < 0) {
         PLOG(FATAL) << "Fail to create epoll";
         return;
     }
-    CHECK_EQ(0, butil::make_close_on_exec(_epfd));
+    CHECK_EQ(0, butil::make_close_on_exec(_event_dispatcher_fd));
 
     _wakeup_fds[0] = -1;
     _wakeup_fds[1] = -1;
@@ -46,9 +45,9 @@ EventDispatcher::EventDispatcher()
 EventDispatcher::~EventDispatcher() {
     Stop();
     Join();
-    if (_epfd >= 0) {
-        close(_epfd);
-        _epfd = -1;
+    if (_event_dispatcher_fd >= 0) {
+        close(_event_dispatcher_fd);
+        _event_dispatcher_fd = -1;
     }
     if (_wakeup_fds[0] > 0) {
         close(_wakeup_fds[0]);
@@ -57,7 +56,7 @@ EventDispatcher::~EventDispatcher() {
 }
 
 int EventDispatcher::Start(const bthread_attr_t* consumer_thread_attr) {
-    if (_epfd < 0) {
+    if (_event_dispatcher_fd < 0) {
         LOG(FATAL) << "epoll was not created";
         return -1;
     }
@@ -68,22 +67,21 @@ int EventDispatcher::Start(const bthread_attr_t* consumer_thread_attr) {
         return -1;
     }
 
-    // Set _consumer_thread_attr before creating epoll thread to make sure
+    // Set _thread_attr before creating epoll thread to make sure
     // everyting seems sane to the thread.
-    _consumer_thread_attr = (consumer_thread_attr  ?
-                             *consumer_thread_attr : BTHREAD_ATTR_NORMAL);
+    _thread_attr = consumer_thread_attr  ?
+        *consumer_thread_attr : BTHREAD_ATTR_NORMAL;
 
-    //_consumer_thread_attr is used in StartInputEvent(), assign flag NEVER_QUIT to it will cause new bthread
+    //_thread_attr is used in StartInputEvent(), assign flag NEVER_QUIT to it will cause new bthread
     // that created by epoll_wait() never to quit.
-    bthread_attr_t epoll_thread_attr = _consumer_thread_attr | BTHREAD_NEVER_QUIT;
+    bthread_attr_t epoll_thread_attr = _thread_attr | BTHREAD_NEVER_QUIT;
 
     // Polling thread uses the same attr for consumer threads (NORMAL right
     // now). Previously, we used small stack (32KB) which may be overflowed
     // when the older comlog (e.g. 3.1.85) calls com_openlog_r(). Since this
     // is also a potential issue for consumer threads, using the same attr
     // should be a reasonable solution.
-    int rc = bthread_start_background(
-        &_tid, &epoll_thread_attr, RunThis, this);
+    int rc = bthread_start_background(&_tid, &epoll_thread_attr, RunThis, this);
     if (rc) {
         LOG(FATAL) << "Fail to create epoll thread: " << berror(rc);
         return -1;
@@ -92,15 +90,15 @@ int EventDispatcher::Start(const bthread_attr_t* consumer_thread_attr) {
 }
 
 bool EventDispatcher::Running() const {
-    return !_stop  && _epfd >= 0 && _tid != 0;
+    return !_stop  && _event_dispatcher_fd >= 0 && _tid != 0;
 }
 
 void EventDispatcher::Stop() {
     _stop = true;
 
-    if (_epfd >= 0) {
+    if (_event_dispatcher_fd >= 0) {
         epoll_event evt = { EPOLLOUT,  { NULL } };
-        epoll_ctl(_epfd, EPOLL_CTL_ADD, _wakeup_fds[1], &evt);
+        epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_ADD, _wakeup_fds[1], &evt);
     }
 }
 
@@ -111,62 +109,62 @@ void EventDispatcher::Join() {
     }
 }
 
-int EventDispatcher::RegisterEvent(SocketId socket_id, int fd, bool pollin) {
-    if (_epfd < 0) {
+int EventDispatcher::RegisterEvent(IOEventDataId event_data_id,
+                                   int fd, bool pollin) {
+    if (_event_dispatcher_fd < 0) {
         errno = EINVAL;
         return -1;
     }
 
     epoll_event evt;
-    evt.data.u64 = socket_id;
+    evt.data.u64 = event_data_id;
     evt.events = EPOLLOUT | EPOLLET;
 #ifdef BRPC_SOCKET_HAS_EOF
     evt.events |= has_epollrdhup;
 #endif
     if (pollin) {
         evt.events |= EPOLLIN;
-        if (epoll_ctl(_epfd, EPOLL_CTL_MOD, fd, &evt) < 0) {
+        if (epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_MOD, fd, &evt) < 0) {
             // This fd has been removed from epoll via `RemoveConsumer',
             // in which case errno will be ENOENT
             return -1;
         }
     } else {
-        if (epoll_ctl(_epfd, EPOLL_CTL_ADD, fd, &evt) < 0) {
+        if (epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_ADD, fd, &evt) < 0) {
             return -1;
         }
     }
     return 0;
 }
 
-int EventDispatcher::UnregisterEvent(SocketId socket_id, 
-                                    int fd, bool pollin) {
+int EventDispatcher::UnregisterEvent(IOEventDataId event_data_id,
+                                     int fd, bool pollin) {
     if (pollin) {
         epoll_event evt;
-        evt.data.u64 = socket_id;
+        evt.data.u64 = event_data_id;
         evt.events = EPOLLIN | EPOLLET;
 #ifdef BRPC_SOCKET_HAS_EOF
         evt.events |= has_epollrdhup;
 #endif
-        return epoll_ctl(_epfd, EPOLL_CTL_MOD, fd, &evt);
+        return epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_MOD, fd, &evt);
     } else {
-        return epoll_ctl(_epfd, EPOLL_CTL_DEL, fd, NULL);
+        return epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_DEL, fd, NULL);
     }
     return -1;
 }
 
-int EventDispatcher::AddConsumer(SocketId socket_id, int fd) {
-    if (_epfd < 0) {
+int EventDispatcher::AddConsumer(IOEventDataId event_data_id, int fd) {
+    if (_event_dispatcher_fd < 0) {
         errno = EINVAL;
         return -1;
     }
     epoll_event evt;
+    evt.data.u64 = event_data_id;
     evt.events = EPOLLIN | EPOLLET;
-    evt.data.u64 = socket_id;
 #ifdef BRPC_SOCKET_HAS_EOF
     evt.events |= has_epollrdhup;
 #endif
-    return epoll_ctl(_epfd, EPOLL_CTL_ADD, fd, &evt);
-    return -1;
+    return epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_ADD, fd, &evt);
 }
 
 int EventDispatcher::RemoveConsumer(int fd) {
@@ -180,8 +178,8 @@ int EventDispatcher::RemoveConsumer(int fd) {
     // from epoll again! If the fd was level-triggered and there's data left,
     // epoll_wait will keep returning events of the fd continuously, making
     // program abnormal.
-    if (epoll_ctl(_epfd, EPOLL_CTL_DEL, fd, NULL) < 0) {
-        PLOG(WARNING) << "Fail to remove fd=" << fd << " from epfd=" << _epfd;
+    if (epoll_ctl(_event_dispatcher_fd, EPOLL_CTL_DEL, fd, NULL) < 0) {
+        PLOG(WARNING) << "Fail to remove fd=" << fd << " from epfd=" << _event_dispatcher_fd;
         return -1;
     }
     return 0;
@@ -197,12 +195,12 @@ void EventDispatcher::Run() {
         epoll_event e[32];
 #ifdef BRPC_ADDITIONAL_EPOLL
         // Performance downgrades in examples.
-        int n = epoll_wait(_epfd, e, ARRAY_SIZE(e), 0);
+        int n = epoll_wait(_event_dispatcher_fd, e, ARRAY_SIZE(e), 0);
         if (n == 0) {
-            n = epoll_wait(_epfd, e, ARRAY_SIZE(e), -1);
+            n = epoll_wait(_event_dispatcher_fd, e, ARRAY_SIZE(e), -1);
         }
 #else
-        const int n = epoll_wait(_epfd, e, ARRAY_SIZE(e), -1);
+        const int n = epoll_wait(_event_dispatcher_fd, e, ARRAY_SIZE(e), -1);
 #endif
         if (_stop) {
             // epoll_ctl/epoll_wait should have some sort of memory fencing
@@ -215,7 +213,7 @@ void EventDispatcher::Run() {
                 // We've checked _stop, no wake-up will be missed.
                 continue;
             }
-            PLOG(FATAL) << "Fail to epoll_wait epfd=" << _epfd;
+            PLOG(FATAL) << "Fail to epoll_wait epfd=" << _event_dispatcher_fd;
             break;
         }
         for (int i = 0; i < n; ++i) {
@@ -225,14 +223,13 @@ void EventDispatcher::Run() {
 #endif
                 ) {
                 // We don't care about the return value.
-                Socket::StartInputEvent(e[i].data.u64, e[i].events,
-                                        _consumer_thread_attr);
+                CallInputEventCallback(e[i].data.u64, e[i].events, _thread_attr);
             }
         }
         for (int i = 0; i < n; ++i) {
             if (e[i].events & (EPOLLOUT | EPOLLERR | EPOLLHUP)) {
                 // We don't care about the return value.
-                Socket::HandleEpollOut(e[i].data.u64);
+                CallOutputEventCallback(e[i].data.u64, e[i].events, _thread_attr);
             }
         }
     }
