@@ -15,25 +15,27 @@
 // specific language governing permissions and limitations
 // under the License.
 
-
-#include <google/protobuf/reflection_ops.h>     // ReflectionOps::Merge
-#include <gflags/gflags.h>
-#include "butil/status.h"
-#include "butil/strings/string_util.h"          // StringToLowerASCII
 #include "brpc/redis.h"
+
+#include <gflags/gflags.h>
+#include <google/protobuf/reflection_ops.h> // ReflectionOps::Merge
+
 #include "brpc/redis_command.h"
+#include "brpc/proto_base.pb.h"
+#include "butil/status.h"
+#include "butil/strings/string_util.h" // StringToLowerASCII
 
 namespace brpc {
 
 DEFINE_bool(redis_verbose_crlf2space, false, "[DEBUG] Show \\r\\n as a space");
 
 RedisRequest::RedisRequest()
-    : ::google::protobuf::Message() {
+    : NonreflectableMessage<RedisRequest>() {
     SharedCtor();
 }
 
 RedisRequest::RedisRequest(const RedisRequest& from)
-    : ::google::protobuf::Message() {
+    : NonreflectableMessage<RedisRequest>() {
     SharedCtor();
     MergeFrom(from);
 }
@@ -55,54 +57,18 @@ void RedisRequest::SetCachedSize(int size) const {
     _cached_size_ = size;
 }
 
-RedisRequest* RedisRequest::New() const {
-    return new RedisRequest;
-}
-
-#if GOOGLE_PROTOBUF_VERSION >= 3006000
-RedisRequest* RedisRequest::New(::google::protobuf::Arena* arena) const {
-    return CreateMaybeMessage<RedisRequest>(arena);
-}
-#endif
-
 void RedisRequest::Clear() {
     _ncommand = 0;
     _has_error = false;
     _buf.clear();
 }
 
-bool RedisRequest::MergePartialFromCodedStream(
-    ::google::protobuf::io::CodedInputStream*) {
-    LOG(WARNING) << "You're not supposed to parse a RedisRequest";
-    return true;
-}
-
-void RedisRequest::SerializeWithCachedSizes(
-    ::google::protobuf::io::CodedOutputStream*) const {
-    LOG(WARNING) << "You're not supposed to serialize a RedisRequest";
-}
-
-::google::protobuf::uint8* RedisRequest::SerializeWithCachedSizesToArray(
-    ::google::protobuf::uint8* target) const {
-    return target;
-}
-
-int RedisRequest::ByteSize() const {
-    int total_size =  _buf.size();
+size_t RedisRequest::ByteSizeLong() const {
+    int total_size =  static_cast<int>(_buf.size());
     _cached_size_ = total_size;
     return total_size;
 }
 
-void RedisRequest::MergeFrom(const ::google::protobuf::Message& from) {
-    CHECK_NE(&from, this);
-    const RedisRequest* source = dynamic_cast<const RedisRequest*>(&from);
-    if (source == NULL) {
-        ::google::protobuf::internal::ReflectionOps::Merge(from, this);
-    } else {
-        MergeFrom(*source);
-    }
-}
-
 void RedisRequest::MergeFrom(const RedisRequest& from) {
     CHECK_NE(&from, this);
     _has_error = _has_error || from._has_error;
@@ -110,18 +76,6 @@ void RedisRequest::MergeFrom(const RedisRequest& from) {
     _ncommand += from._ncommand;
 }
 
-void RedisRequest::CopyFrom(const ::google::protobuf::Message& from) {
-    if (&from == this) return;
-    Clear();
-    MergeFrom(from);
-}
-
-void RedisRequest::CopyFrom(const RedisRequest& from) {
-    if (&from == this) return;
-    Clear();
-    MergeFrom(from);
-}
-
 bool RedisRequest::IsInitialized() const {
     return _ncommand != 0;
 }
@@ -208,14 +162,10 @@ bool RedisRequest::SerializeTo(butil::IOBuf* buf) const {
     return true;
 }
 
-const ::google::protobuf::Descriptor* RedisRequest::descriptor() {
-    return RedisRequestBase::descriptor();
-}
-
 ::google::protobuf::Metadata RedisRequest::GetMetadata() const {
-    ::google::protobuf::Metadata metadata;
-    metadata.descriptor = RedisRequest::descriptor();
-    metadata.reflection = NULL;
+    ::google::protobuf::Metadata metadata{};
+    metadata.descriptor = RedisRequestBase::descriptor();
+    metadata.reflection = nullptr;
     return metadata;
 }
 
@@ -245,12 +195,12 @@ std::ostream& operator<<(std::ostream& os, const RedisRequest& r) {
 }
 
 RedisResponse::RedisResponse()
-    : ::google::protobuf::Message()
+    : NonreflectableMessage<RedisResponse>()
     , _first_reply(&_arena) {
     SharedCtor();
 }
 RedisResponse::RedisResponse(const RedisResponse& from)
-    : ::google::protobuf::Message()
+    : NonreflectableMessage<RedisResponse>()
     , _first_reply(&_arena) {
     SharedCtor();
     MergeFrom(from);
@@ -273,16 +223,6 @@ void RedisResponse::SetCachedSize(int size) const {
     _cached_size_ = size;
 }
 
-RedisResponse* RedisResponse::New() const {
-    return new RedisResponse;
-}
-
-#if GOOGLE_PROTOBUF_VERSION >= 3006000
-RedisResponse* RedisResponse::New(::google::protobuf::Arena* arena) const {
-    return CreateMaybeMessage<RedisResponse>(arena);
-}
-#endif
-
 void RedisResponse::Clear() {
     _first_reply.Reset();
     _other_replies = NULL;
@@ -291,36 +231,10 @@ void RedisResponse::Clear() {
     _cached_size_ = 0;
 }
 
-bool RedisResponse::MergePartialFromCodedStream(
-    ::google::protobuf::io::CodedInputStream*) {
-    LOG(WARNING) << "You're not supposed to parse a RedisResponse";
-    return true;
-}
-
-void RedisResponse::SerializeWithCachedSizes(
-    ::google::protobuf::io::CodedOutputStream*) const {
-    LOG(WARNING) << "You're not supposed to serialize a RedisResponse";
-}
-
-::google::protobuf::uint8* RedisResponse::SerializeWithCachedSizesToArray(
-    ::google::protobuf::uint8* target) const {
-    return target;
-}
-
-int RedisResponse::ByteSize() const {
+size_t RedisResponse::ByteSizeLong() const {
     return _cached_size_;
 }
 
-void RedisResponse::MergeFrom(const ::google::protobuf::Message& from) {
-    CHECK_NE(&from, this);
-    const RedisResponse* source = dynamic_cast<const RedisResponse*>(&from);
-    if (source == NULL) {
-        ::google::protobuf::internal::ReflectionOps::Merge(from, this);
-    } else {
-        MergeFrom(*source);
-    }
-}
-
 void RedisResponse::MergeFrom(const RedisResponse& from) {
     CHECK_NE(&from, this);
     if (from._nreply == 0) {
@@ -353,18 +267,6 @@ void RedisResponse::MergeFrom(const RedisResponse& from) {
     _nreply = new_nreply;
 }
 
-void RedisResponse::CopyFrom(const ::google::protobuf::Message& from) {
-    if (&from == this) return;
-    Clear();
-    MergeFrom(from);
-}
-
-void RedisResponse::CopyFrom(const RedisResponse& from) {
-    if (&from == this) return;
-    Clear();
-    MergeFrom(from);
-}
-
 bool RedisResponse::IsInitialized() const {
     return reply_size() > 0;
 }
@@ -379,14 +281,10 @@ void RedisResponse::Swap(RedisResponse* other) {
     }
 }
 
-const ::google::protobuf::Descriptor* RedisResponse::descriptor() {
-    return RedisResponseBase::descriptor();
-}
-
 ::google::protobuf::Metadata RedisResponse::GetMetadata() const {
-    ::google::protobuf::Metadata metadata;
-    metadata.descriptor = RedisResponse::descriptor();
-    metadata.reflection = NULL;
+    ::google::protobuf::Metadata metadata{};
+    metadata.descriptor = RedisResponseBase::descriptor();
+    metadata.reflection = nullptr;
     return metadata;
 }
 
