@@ -25,11 +25,11 @@
 #include <iostream>                      // std::ostream
 #include <pthread.h>                     // pthread_mutex_t
 #include <algorithm>                     // std::max, std::min
-#include "butil/atomicops.h"              // butil::atomic
-#include "butil/macros.h"                 // BAIDU_CACHELINE_ALIGNMENT
-#include "butil/scoped_lock.h"            // BAIDU_SCOPED_LOCK
-#include "butil/thread_local.h"           // thread_atexit
-#include "butil/memory/manual_constructor.h"
+#include "butil/atomicops.h"             // butil::atomic
+#include "butil/macros.h"                // BAIDU_CACHELINE_ALIGNMENT
+#include "butil/scoped_lock.h"           // BAIDU_SCOPED_LOCK
+#include "butil/thread_local.h"          // thread_atexit
+#include "butil/memory/aligned_memory.h" // butil::AlignedMemory
 #include <vector>
 
 #ifdef BUTIL_RESOURCE_POOL_NEED_FREE_ITEM_NUM
@@ -110,11 +110,12 @@ public:
     typedef ResourcePoolFreeChunk<T, FREE_CHUNK_NITEM>      FreeChunk;
     typedef ResourcePoolFreeChunk<T, 0> DynamicFreeChunk;
 
+    typedef AlignedMemory<sizeof(T), __alignof__(T)> BlockItem;
     // When a thread needs memory, it allocates a Block. To improve locality,
     // items in the Block are only used by the thread.
     // To support cache-aligned objects, align Block.items by cacheline.
     struct BAIDU_CACHELINE_ALIGNMENT Block {
-        ManualConstructor<T> items[BLOCK_NITEM];
+        BlockItem items[BLOCK_NITEM];
         size_t nitem;
 
         Block() : nitem(0) {}
@@ -163,7 +164,7 @@ public:
         // which may include parenthesis because when T is POD, "new T()"
         // and "new T" are different: former one sets all fields to 0 which
         // we don't want.
-#define BAIDU_RESOURCE_POOL_GET(...)                                        \
+#define BAIDU_RESOURCE_POOL_GET(CTOR_ARGS)                                  \
         /* Fetch local free id */                                           \
         if (_cur_free.nfree) {                                              \
             const ResourceId<T> free_id = _cur_free.ids[--_cur_free.nfree]; \
@@ -182,13 +183,11 @@ public:
             return unsafe_address_resource(free_id);                        \
         }                                                                   \
         T* p = NULL;                                                        \
-        auto ctor = [&](void* mem) {                                        \
-            p = new (mem) T(__VA_ARGS__);                                   \
-        };                                                                  \
         /* Fetch memory from local block */                                 \
         if (_cur_block && _cur_block->nitem < BLOCK_NITEM) {                \
             id->value = _cur_block_index * BLOCK_NITEM + _cur_block->nitem; \
-            (_cur_block->items + _cur_block->nitem)->InitBy(ctor);          \
+            auto item = _cur_block->items + _cur_block->nitem;              \
+            p = new (item->void_data()) T CTOR_ARGS;                        \
             if (!ResourcePoolValidator<T>::validate(p)) {                   \
                 p->~T();                                                    \
                 return NULL;                                                \
@@ -200,7 +199,8 @@ public:
         _cur_block = add_block(&_cur_block_index);                          \
         if (_cur_block != NULL) {                                           \
             id->value = _cur_block_index * BLOCK_NITEM + _cur_block->nitem; \
-            (_cur_block->items + _cur_block->nitem)->InitBy(ctor);          \
+            auto item = _cur_block->items + _cur_block->nitem;              \
+            p = new (item->void_data()) T CTOR_ARGS;                        \
             if (!ResourcePoolValidator<T>::validate(p)) {                   \
                 p->~T();                                                    \
                 return NULL;                                                \
@@ -215,14 +215,9 @@ public:
             BAIDU_RESOURCE_POOL_GET();
         }
 
-        template <typename A1>
-        inline T* get(ResourceId<T>* id, const A1& a1) {
-            BAIDU_RESOURCE_POOL_GET(a1);
-        }
-
-        template <typename A1, typename A2>
-        inline T* get(ResourceId<T>* id, const A1& a1, const A2& a2) {
-            BAIDU_RESOURCE_POOL_GET(a1, a2);
+        template<typename... Args>
+        inline T* get(ResourceId<T>* id, Args&&... args) {
+            BAIDU_RESOURCE_POOL_GET((std::forward<Args>(args)...));
         }
 
 #undef BAIDU_RESOURCE_POOL_GET
@@ -282,28 +277,11 @@ public:
         return NULL;
     }
 
-    inline T* get_resource(ResourceId<T>* id) {
+    template<typename... Args>
+    inline T* get_resource(ResourceId<T>* id, Args&&... args) {
         LocalPool* lp = get_or_new_local_pool();
         if (__builtin_expect(lp != NULL, 1)) {
-            return lp->get(id);
-        }
-        return NULL;
-    }
-
-    template <typename A1>
-    inline T* get_resource(ResourceId<T>* id, const A1& arg1) {
-        LocalPool* lp = get_or_new_local_pool();
-        if (__builtin_expect(lp != NULL, 1)) {
-            return lp->get(id, arg1);
-        }
-        return NULL;
-    }
-
-    template <typename A1, typename A2>
-    inline T* get_resource(ResourceId<T>* id, const A1& arg1, const A2& arg2) {
-        LocalPool* lp = get_or_new_local_pool();
-        if (__builtin_expect(lp != NULL, 1)) {
-            return lp->get(id, arg1, arg2);
+            return lp->get(id, std::forward<Args>(args)...);
         }
         return NULL;
     }
