@@ -23,6 +23,10 @@
 #include "butil/logging.h"
 #include "butil/containers/flat_map.h"
 #include "butil/details/extended_endpoint.hpp"
+#include <netinet/tcp.h>
+#if defined(OS_MACOSX)
+#include <netinet/tcp_fsm.h>
+#endif
 
 namespace butil {
 int pthread_timed_connect(int sockfd, const struct sockaddr* serv_addr,
@@ -528,4 +532,68 @@ TEST(EndPointTest, tcp_connect) {
     }
 }
 
+bool g_connect_startd = false;
+
+void TestConnectInterruptImpl(bool timed) {
+    butil::EndPoint ep;
+    ASSERT_EQ(0, butil::hostname2endpoint(g_hostname, 80, &ep));
+
+    struct sockaddr_storage serv_addr{};
+    socklen_t serv_addr_size = 0;
+    ASSERT_EQ(0, endpoint2sockaddr(ep, &serv_addr, &serv_addr_size));
+    butil::fd_guard sockfd(socket(serv_addr.ss_family, SOCK_STREAM, 0));
+    ASSERT_LE(0, sockfd);
+
+    int rc;
+    if (timed) {
+        int64_t start_ms = butil::cpuwide_time_ms();
+        butil::tcp_connect(ep, NULL);
+        int64_t connect_ms = butil::cpuwide_time_ms() - start_ms;
+        LOG(INFO) << "Connect to " << ep << ", cost " << connect_ms << "ms";
+
+        timespec abstime = butil::milliseconds_from_now(connect_ms * 2);
+        rc = butil::pthread_timed_connect(
+            sockfd, (struct sockaddr*) &serv_addr,
+            serv_addr_size, &abstime);
+    } else {
+        rc = butil::pthread_timed_connect(
+            sockfd, (struct sockaddr*) &serv_addr,
+            serv_addr_size, NULL);
+    }
+    ASSERT_EQ(0, rc) << "errno=" << errno;
+    ASSERT_EQ(0, butil::is_connected(sockfd));
+}
+
+void* ConnectThread(void* arg) {
+    bool timed = *(bool*)arg;
+    TestConnectInterruptImpl(timed);
+    return NULL;
+}
+
+void do_nothing_handler(int) {}
+
+void register_sigurg() {
+    signal(SIGURG, do_nothing_handler);
+}
+
+void TestConnectInterrupt(bool timed) {
+    g_connect_startd = false;
+    pthread_t tid;
+    ASSERT_EQ(0, pthread_create(&tid, NULL, ConnectThread, &timed));
+
+    while (g_connect_startd) {
+        usleep(1000);
+    }
+
+    ASSERT_EQ(0, pthread_kill(tid, SIGURG));
+
+    pthread_join(tid, NULL);
+}
+
+TEST(EndPointTest, interrupt) {
+    register_sigurg();
+    TestConnectInterrupt(false);
+    TestConnectInterrupt(true);
+}
+
 } // end of namespace
