@@ -59,8 +59,8 @@ public:
         ::logging::FLAGS_crash_on_fatal_log = _old_crash_on_fatal_log;
         if (::logging::FLAGS_v != 0) {
             // Clear -verbose to avoid affecting other tests.
-            ASSERT_FALSE(GFLAGS_NS::SetCommandLineOption("v", "0").empty());
-            ASSERT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule", "").empty());
+            ASSERT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("v", "0").empty());
+            ASSERT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule", "").empty());
         }
     }
 private:
@@ -218,11 +218,11 @@ TEST_F(LoggingTest, log_at) {
 TEST_F(LoggingTest, vlog_sanity) {
     ::logging::FLAGS_crash_on_fatal_log = false;
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("v", "1").empty());
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("v", "1").empty());
     
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
                                                "logging_unittest=1").empty());
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
                                                "logging_UNITTEST=2").empty());
 
     for (int i = 0; i < 10; ++i) {
@@ -238,7 +238,7 @@ TEST_F(LoggingTest, vlog_sanity) {
     VLOG_NE(0) << "always on";
     EXPECT_EQ("always on", LOG_STREAM(INFO).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
                                               "logging_unittest=0").empty());
     for (int i = 0; i < 10; ++i) {
         VLOG_NE(i) << "vlog " << i;
@@ -246,7 +246,7 @@ TEST_F(LoggingTest, vlog_sanity) {
     EXPECT_EQ("", LOG_STREAM(VERBOSE).content_str());
     EXPECT_EQ("vlog 0", LOG_STREAM(INFO).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
                      "logging_unittest=0,logging_unittest=1").empty());
     for (int i = 0; i < 10; ++i) {
         VLOG_NE(i) << "vlog " << i;
@@ -254,7 +254,7 @@ TEST_F(LoggingTest, vlog_sanity) {
     EXPECT_EQ("vlog 1", LOG_STREAM(VERBOSE).content_str());
     EXPECT_EQ("vlog 0", LOG_STREAM(INFO).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
                      "logging_unittest=1,logging_unittest=0").empty());
     for (int i = 0; i < 10; ++i) {
         VLOG_NE(i) << "vlog " << i;
@@ -262,14 +262,14 @@ TEST_F(LoggingTest, vlog_sanity) {
     EXPECT_EQ("", LOG_STREAM(VERBOSE).content_str());
     EXPECT_EQ("vlog 0", LOG_STREAM(INFO).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule", "").empty());
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule", "").empty());
     for (int i = 0; i < 10; ++i) {
         VLOG_NE(i) << "vlog " << i;
     }
     EXPECT_EQ("vlog 1", LOG_STREAM(VERBOSE).content_str());
     EXPECT_EQ("vlog 0", LOG_STREAM(INFO).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
                                                "logg?ng_*=2").empty());
     for (int i = 0; i < 10; ++i) {
         VLOG_NE(i) << "vlog " << i;
@@ -277,7 +277,7 @@ TEST_F(LoggingTest, vlog_sanity) {
     EXPECT_EQ("vlog 1vlog 2", LOG_STREAM(VERBOSE).content_str());
     EXPECT_EQ("vlog 0", LOG_STREAM(INFO).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule",
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule",
         "foo=3,logging_unittest=3, logg?ng_*=2 , logging_*=1 ").empty());
     for (int i = 0; i < 10; ++i) {
         VLOG_NE(i) << "vlog " << i;
@@ -290,7 +290,7 @@ TEST_F(LoggingTest, vlog_sanity) {
     }
     EXPECT_EQ("vlog 1vlog 3", LOG_STREAM(VERBOSE).content_str());
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption(
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption(
                      "vmodule",
                      "foo/bar0/0=2,foo/bar/1=3, 2=4, foo/*/3=5, */ba?/4=6,"
                      "/5=7,/foo/bar/6=8,foo2/bar/7=9,foo/bar/8=9").empty());
@@ -373,8 +373,8 @@ TEST_F(LoggingTest, debug_level) {
     DLOG(NOTICE) << foo(&run_foo);
     DLOG(DEBUG) << foo(&run_foo);
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("vmodule", "").empty());
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("v", "1").empty());
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("vmodule", "").empty());
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("v", "1").empty());
     DVLOG(1) << foo(&run_foo);
     DVLOG2("a/b/c", 1) << foo(&run_foo);
 
@@ -470,7 +470,7 @@ void CheckFunctionName() {
     ASSERT_NE(std::string::npos, log_str.find("specified_file.cc:12345 log_at"));
     ::logging::SetLogSink(old_sink);
 
-    EXPECT_FALSE(GFLAGS_NS::SetCommandLineOption("v", "1").empty());
+    EXPECT_FALSE(GFLAGS_NAMESPACE::SetCommandLineOption("v", "1").empty());
     VLOG(100) << "test" << noflush;
     ASSERT_EQ(func_name, VLOG_STREAM(100).func());
 }
